@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -19,9 +19,7 @@ StatusSearchLine::StatusSearchLine(QWidget *parent)
     initializeActions();
 }
 
-StatusSearchLine::~StatusSearchLine()
-{
-}
+StatusSearchLine::~StatusSearchLine() = default;
 
 void StatusSearchLine::keyPressEvent(QKeyEvent *e)
 {
